@@ -8,10 +8,11 @@ async def get_raw_content_from_url(req_url: str) -> tuple[bytes, str]:
     return file_data, media_type
 
 
+# Base64 Encoded
 async def get_encoded_content_from_url(req_url: str) -> tuple[str, str]:
-    img_data, media_type = await get_raw_content_from_url(req_url)
-    base64_image = base64.b64encode(img_data).decode('utf-8')
-    return base64_image, media_type
+    media_data, media_type = await get_raw_content_from_url(req_url)
+    base64_media = base64.b64encode(media_data).decode('utf-8')
+    return base64_media, media_type
 
 
 async def get_openai_image_content_from_url(req_img_url: str) -> str:
