@@ -2,7 +2,10 @@ import re
 
 import openai
 from fastapi import HTTPException
+from openai.types import Reasoning
 from openai.types.responses import WebSearchToolParam
+from openai.types.responses.tool_param import CodeInterpreter, CodeInterpreterContainerCodeInterpreterToolAuto, \
+    ImageGeneration
 
 from llm_bridge.client.implementations.openai.non_stream_openai_client import NonStreamOpenAIClient
 from llm_bridge.client.implementations.openai.non_stream_openai_responses_client import NonStreamOpenAIResponsesClient
@@ -54,20 +57,32 @@ async def create_openai_client(
     else:
         openai_messages = await convert_messages_to_openai(messages)
 
-    tools = [
-        WebSearchToolParam(
-            type="web_search_preview",
-            search_context_size="high",
-        )
-    ]
+    tools = []
+    reasoning = None
 
-    if re.match(r"^o\d", model):
-        tools = None
+    if model not in ["gpt-5-chat-latest", "gpt-5-pro"]:
+        tools.append(
+            CodeInterpreter(
+                type="code_interpreter",
+                container=CodeInterpreterContainerCodeInterpreterToolAuto(type="auto")
+            )
+        )
+    if model not in ["gpt-5-chat-latest"]:
+        tools.append(
+            WebSearchToolParam(
+                type="web_search",
+                search_context_size="high",
+            )
+        )
+    if re.match(r"^o\d", model) or (re.match(r"gpt-5.*", model) and model != "gpt-5-chat-latest"):
         temperature = 1
-    if re.match(r"gpt-5.*", model):
-        temperature = 1
-    if model == "gpt-5-chat-latest":
-        tools = None
+    if re.match(r"gpt-5.*", model) and model != "gpt-5-chat-latest":
+        reasoning = Reasoning(effort="high")
+        tools.append(
+            ImageGeneration(
+                type="image_generation",
+            )
+        )
 
     if use_responses_api:
         if stream:
@@ -78,6 +93,7 @@ async def create_openai_client(
                 api_type=api_type,
                 client=client,
                 tools=tools,
+                reasoning=reasoning,
             )
         else:
             return NonStreamOpenAIResponsesClient(
@@ -87,6 +103,7 @@ async def create_openai_client(
                 api_type=api_type,
                 client=client,
                 tools=tools,
+                reasoning=reasoning,
             )
     else:
         if stream:
@@ -97,6 +114,7 @@ async def create_openai_client(
                 api_type=api_type,
                 client=client,
                 tools=tools,
+                reasoning=reasoning,
             )
         else:
             return NonStreamOpenAIClient(
@@ -106,4 +124,5 @@ async def create_openai_client(
                 api_type=api_type,
                 client=client,
                 tools=tools,
+                reasoning=reasoning,
             )
